VRBindings class

Registers VR engine services into Sint dependency injection.

VRBindings.register();
final engine = Sint.find<VREngine>();
final raycaster = Sint.find<Raycaster>();

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

register({DeviceParams deviceParams = DeviceParams.cardboardV2}) → void
Registers all VR services as lazy singletons.
unregister() → void
Unregisters all VR services.