onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
engine = VREngine();
engine.onUpdate = (dt) {
currentFps.value = engine.fps;
onVRUpdate(dt);
};
onVRInit();
engine.start();
}