VRSceneState class
Reactive wrapper around VREngine scene for Sint state management. Tracks node count, light count, and scene changes reactively.
Constructors
- VRSceneState(VREngine engine)
Properties
- engine → VREngine
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → RxBool
-
final
- lightCount → RxInt
-
final
- nodeCount → RxInt
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNode(
Node node) → void -
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeNode(
Node node) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited